Struct snarkvm_objects::amount::AleoAmount [−][src]
pub struct AleoAmount(pub i64);
Represents the amount of ALEOs in UNITS
Implementations
impl AleoAmount[src]
impl AleoAmount[src]pub const ONE_ALEO: AleoAmount[src]
pub const ONE_ALEO: AleoAmount[src]Exactly one ALEO.
pub const ONE_BYTE: AleoAmount[src]
pub const ONE_BYTE: AleoAmount[src]Exactly one byte.
pub const ZERO: AleoAmount[src]
pub const ZERO: AleoAmount[src]The zero amount.
pub fn from_bytes(bytes: i64) -> Self[src]
pub fn from_bytes(bytes: i64) -> Self[src]Create an AleoAmount given a number of bytes
pub fn from_gates(gate_value: i64) -> Self[src]
pub fn from_gates(gate_value: i64) -> Self[src]Create an AleoAmount given a number of gates
pub fn sub(self, b: AleoAmount) -> Self[src]
pub fn sub(self, b: AleoAmount) -> Self[src]Subtract the value of two AleoAmounts
pub const fn is_positive(self) -> bool[src]
pub const fn is_positive(self) -> bool[src]Returns true the amount is positive and false if the amount is zero or
negative.
pub const fn is_negative(self) -> bool[src]
pub const fn is_negative(self) -> bool[src]Returns true if the amount is negative and false if the amount is zero or
positive.